@@ -1,6 +1,6 @@
 # Copyright (c) Stephan Martin <sm@sm-zone.net>
 #
-# $Id: CERT.pm,v 1.3 2005/03/31 20:51:39 sm Exp $
+# $Id: CERT.pm,v 1.9 2006/05/23 16:55:43 sm Exp $
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -115,8 +115,8 @@ sub read_certlist {
    $self->{'lastread'} = time();
 
    if(defined($main)) {
-      $main->{'barbox'}->remove($main->{'progress'});
       $main->{'progress'}->set_fraction(0);
+      $main->{'barbox'}->remove($main->{'progress'});
       GUI::HELPERS::set_cursor($main, 0);
    }
 
@@ -390,11 +390,10 @@ sub get_export_cert {
       $opts->{'cert'}   = $main->{'certbrowser'}->selection_dn();
 
       $opts->{'certname'} = MIME::Base64::encode($opts->{'cert'}, '');
-      $opts->{'certfile'} = 
-         $cadir."/certs/".$opts->{'certname'}.".pem";
-      $opts->{'keyfile'}  = 
-         $cadir."/keys/".$opts->{'certname'}.".pem";
+      $opts->{'certfile'} = $cadir."/certs/".$opts->{'certname'}.".pem";
+      $opts->{'keyfile'}  = $cadir."/keys/".$opts->{'certname'}.".pem";
       $opts->{'cafile'}   = $cadir."/cacert.pem";
+
       if (-f $cadir."/cachain.pem") {
          $opts->{'cafile'} = $cadir."/cachain.pem";
       }
@@ -416,9 +415,11 @@ sub get_export_cert {
       }else{
          $opts->{'outfile'} = "$main->{'exportdir'}/cert.pem";
       }
-      $opts->{'format'}  = 'PEM';
-      $opts->{'include'} = 0;
-      $opts->{'incfp'}   = 0;
+      $opts->{'format'}       = 'PEM';
+      $opts->{'include'}      = 0;
+      $opts->{'incfp'}        = 0;
+      $opts->{'nopass'}       = 0;
+      $opts->{'friendlyname'} = '';
 
       $main->show_export_dialog($opts, 'cert');
       return;
@@ -440,14 +441,16 @@ sub get_export_cert {
          return;
       }
 
-      if(not defined($opts->{'p12passwd'})) {
+      if((not defined($opts->{'p12passwd'})) &&
+            (not $opts->{'nopass'})) {
          $opts->{'includeca'} = 1;
          $main->show_p12_export_dialog($opts, 'cert');
          return;
       }
-   } elsif($opts->{'format'} eq 'ZIP') {
+   } elsif(($opts->{'format'} eq 'ZIP') || ($opts->{'format'} eq 'TAR')) {
       if(not -s $opts->{'keyfile'}) {
-         $t = gettext("Key is necessary for export as Zip");
+         $t = sprintf(
+               gettext("Key is necessary for export as %s"), $opts->{'format'});
          $t .= "\n";
          $t .= gettext("Export is not possible!");
          GUI::HELPERS::print_warning($t);
@@ -477,10 +480,11 @@ sub export_cert {
       if($opts->{'incfp'}) {
          $out = '';
          $out .= "Fingerprint (MD5): $opts->{'parsed'}->{'FINGERPRINTMD5'}\n";
-         $out .= "Fingerprint (SHA1): $opts->{'parsed'}->{'FINGERPRINTSHA1'}\n";
+         $out .= "Fingerprint (SHA1): $opts->{'parsed'}->{'FINGERPRINTSHA1'}\n\n";
       } else {
          $out = '';
       }
+
       $out .= $opts->{'parsed'}->{'PEM'};
 
       if($opts->{'include'}) {
@@ -507,7 +511,9 @@ sub export_cert {
             outfile   => $opts->{'outfile'},
             passwd    => $opts->{'passwd'},
             p12passwd => $opts->{'p12passwd'},
-            includeca => $opts->{'includeca'}
+            includeca => $opts->{'includeca'},
+            nopass    => $opts->{'nopass'},
+            friendly  => $opts->{'friendlyname'}
             );
 
       GUI::HELPERS::set_cursor($main, 0);
@@ -530,7 +536,7 @@ sub export_cert {
       GUI::HELPERS::print_info($t, $ext);
       return;
 
-   } elsif ($opts->{'format'} eq "ZIP") {
+   } elsif (($opts->{'format'} eq "ZIP") || ($opts->{'format'} eq "TAR")) {
 
       my $tmpcert   = "$main->{'tmpdir'}/cert.pem";
       my $tmpkey    = "$main->{'tmpdir'}/key.pem";
@@ -588,14 +594,21 @@ sub export_cert {
       }
 
       unlink($opts->{'outfile'});
-      system($main->{'init'}->{'zipbin'}, '-j', $opts->{'outfile'}, $tmpcacert, 
-             $tmpkey, $tmpcert);
-      my $ret = $? >> 8;
+      if($opts->{'format'} eq "ZIP") {
+         system($main->{'init'}->{'zipbin'}, '-j', $opts->{'outfile'},
+               $tmpcacert, $tmpkey, $tmpcert); 
+         my $ret = $? >> 8;
+      } elsif ($opts->{'format'} eq "TAR") {
+         system($main->{'init'}->{'tarbin'}, 'cfv', $opts->{'outfile'},
+               $tmpcacert, $tmpkey, $tmpcert); 
+      }
 
       GUI::HELPERS::set_cursor($main, 0);
 
       if(not -s $opts->{'outfile'} || $ret) {
-         GUI::HELPERS::print_warning(gettext("Generating Zip file failed"));
+         GUI::HELPERS::print_warning(
+               sprintf(gettext("Generating %s file failed"), $opts->{'format'})
+               );
       } else {
          $main->{'exportdir'} = HELPERS::write_export_dir($main, 
                $opts->{'outfile'});
