@@ -1,6 +1,6 @@
 # Copyright (c) Stephan Martin <sm@sm-zone.net>
 #
-# $Id: KEY.pm,v 1.3 2005/04/08 13:48:11 sm Exp $
+# $Id: KEY.pm,v 1.6 2006/05/23 16:55:43 sm Exp $
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -151,9 +151,10 @@ sub get_export_key {
       $opts->{'certfile'} = $cadir."/certs/".$opts->{'keyname'}.".pem";
       
       # set some defaults
-      $opts->{'nopass'}  = 0;
-      $opts->{'include'} = 0;
-      $opts->{'format'}  = 'PEM';
+      $opts->{'nopass'}        = 0;
+      $opts->{'include'}       = 0;
+      $opts->{'format'}        = 'PEM';
+      $opts->{'friendlyname'}  = '';
 
       if((defined($email)) && $email ne '' && $email ne ' ') {
          $opts->{'outfile'} = "$main->{'exportdir'}/$email-key.pem";
@@ -173,13 +174,6 @@ sub get_export_key {
       return;
    }
 
-   if($opts->{'nopass'} && $opts->{'format'} eq 'P12') {
-      $main->show_export_dialog($opts, 'key');
-      GUI::HELPERS::print_warning(
-            gettext("Can't export PKCS#12 without passphrase"));
-      return;
-   }
-
    if(($opts->{'nopass'} || $opts->{'format'} eq 'DER') && 
       ((not defined($opts->{'passwd'})) || ($opts->{'passwd'} eq ''))) {
       $main->show_key_nopasswd_dialog($opts);
@@ -266,7 +260,8 @@ sub get_export_key {
          return;
       }
 
-      if(not defined($opts->{'p12passwd'})) {
+      if((not defined($opts->{'p12passwd'})) &&
+            (not $opts->{'nopass'})) {
          $opts->{'includeca'} = 1;
          $main->show_p12_export_dialog($opts, 'key');
          return;
@@ -281,7 +276,9 @@ sub get_export_key {
             outfile   => $opts->{'outfile'},
             passwd    => $opts->{'passwd'},
             p12passwd => $opts->{'p12passwd'},
-            includeca => $opts->{'includeca'}
+            includeca => $opts->{'includeca'},
+            nopass    => $opts->{'nopass'},
+            friendly  => $opts->{'friendlyname'}
             );
 
       if($ret eq 1) {
@@ -301,11 +298,13 @@ sub get_export_key {
       GUI::HELPERS::print_info($t, $ext);
       return;
 
-   } elsif ($opts->{'format'} eq "ZIP") {
+   } elsif (($opts->{'format'} eq "ZIP") || ($opts->{'format'} eq "TAR")) {
       $opts->{'certfile'} = 
          $main->{'cadir'}."/certs/".$opts->{'keyname'}.".pem";
       if(not -s $opts->{'certfile'}) {
-         $t = gettext("Certificate is necessary for export as Zip file");
+         $t = sprintf(
+               gettext("Certificate is necessary for export as %s file"), 
+               $opts->{'format'});
          $t .= "\n";
          $t .= gettext("Export is not possible!");
          GUI::HELPERS::print_warning($t);
@@ -362,12 +361,20 @@ sub get_export_key {
       }
 
       unlink($opts->{'outfile'});
-      system($main->{'init'}->{'zipbin'}, '-j', $opts->{'outfile'},
-            $tmpcacert, $tmpkey, $tmpcert); 
-      my $ret = $? >> 8;
+      if($opts->{'format'} eq 'ZIP') { 
+         system($main->{'init'}->{'zipbin'}, '-j', $opts->{'outfile'},
+               $tmpcacert, $tmpkey, $tmpcert); 
+         my $ret = $? >> 8;
+      } elsif ($opts->{'format'} eq 'TAR') {
+         system($main->{'init'}->{'tarbin'}, 'cfv', $opts->{'outfile'},
+               $tmpcacert, $tmpkey, $tmpcert); 
+         my $ret = $? >> 8;
+      }
 
       if(not -s $opts->{'outfile'} || $ret) {
-         GUI::HELPERS::print_warning(gettext("Generating Zip file failed"));
+         GUI::HELPERS::print_warning(
+               sprintf(gettext("Generating %s file failed"), 
+                  $opts->{'format'}));
       } else {
          $main->{'exportdir'} = HELPERS::write_export_dir($main, 
                $opts->{'outfile'});
