@@ -1,6 +1,6 @@
 # Copyright (c) Stephan Martin <sm@sm-zone.net>
 #
-# $Id: OpenSSL.pm,v 1.3 2005/05/21 17:14:58 sm Exp $
+# $Id: OpenSSL.pm,v 1.11 2006/05/23 16:55:43 sm Exp $
 # 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,12 +41,16 @@ sub new {
    my $v = <TEST>;
    close(TEST);
 
-   if($v =~ /0.9.6/) {
-      $self->{'version'} = "0.9.6";
-   } elsif ($v =~ /0.9.7/) {
-      $self->{'version'} = "0.9.7";
-   } elsif ($v =~ /0.9.8/) {
-      $self->{'version'} = "0.9.8";
+   # set version (format: e.g. 0.9.7 or 0.9.7a)
+   if($v =~ /\b(0\.9\.[678][a-z]?)\b/) {
+      $self->{'version'} = $1;
+   }
+
+   # CRL output was broken before openssl 0.9.7f   
+   if($v =~ /\b0\.9\.[0-6][a-z]?\b/ || $v =~ /\b0\.9\.7[a-e]?\b/)  { 
+      $self->{'broken'} = 1; 
+   } else { 
+      $self->{'broken'} = 0; 
    }
 
    bless($self, $class);
@@ -139,6 +143,7 @@ sub signreq {
    $cmd .= " -in \"$opts->{'reqfile'}\"";
    $cmd .= " -days $opts->{'days'}";
    $cmd .= " -preserveDN";
+   $cmd .= " -md $opts->{'digest'}" if($opts->{'digest'});
 
    if(defined($opts->{'mode'}) && $opts->{'mode'} eq "sub") {
       $cmd .= " -keyfile \"$opts->{'keyfile'}\"";
@@ -631,7 +636,7 @@ sub parsecert {
    $tmp->{'EXT'} = HELPERS::parse_extensions(\@lines, "cert");
 
    # get fingerprint 
-   $cmd = "$self->{'bin'} x509 -noout -fingerprint -in $file";
+   $cmd = "$self->{'bin'} x509 -noout -fingerprint -md5 -in $file";
    my($rdfh, $wtfh);
    $ext = "$cmd\n\n";
    $pid = open3($wtfh, $rdfh, $rdfh, $cmd);
@@ -834,13 +839,22 @@ sub convdata {
    waitpid($pid, 0);
    $ret = $?>>8;
 
-   if(($ret != 0 && $opts->{'cmd'} ne 'crl') ||
-      ($ret != 0 && $opts->{'outform'} ne 'TEXT' && $opts->{'cmd'} eq 'crl') ||
-      ($ret != 1 && $opts->{'outform'} eq 'TEXT' && $opts->{'cmd'} eq 'crl')) { 
-      unlink($file);
-      return($ret, undef, $ext);
-   } else {
-      $ret = 0;
+   if($self->{'broken'}) {
+       if(($ret != 0 && $opts->{'cmd'} ne 'crl') ||
+          ($ret != 0 && $opts->{'outform'} ne 'TEXT' && $opts->{'cmd'} eq 'crl') ||
+          ($ret != 1 && $opts->{'outform'} eq 'TEXT' && $opts->{'cmd'} eq 'crl')) { 
+          unlink($file);
+          return($ret, undef, $ext);
+       } else {
+          $ret = 0;
+       }
+   } else { # wow, they fixed it :-)
+      if($ret != 0) { 
+         unlink($file); 
+         return($ret, undef, $ext); 
+      } else { 
+         $ret = 0; 
+      }
    }
 
    open(IN, $file) || do {
@@ -923,11 +937,18 @@ sub genp12 {
    $cmd .= " -out \"$opts->{'outfile'}\"";
    $cmd .= " -in \"$opts->{'certfile'}\"";
    $cmd .= " -inkey \"$opts->{'keyfile'}\"";
-   $cmd .= " -passout env:P12PASS";
+   if(not $opts->{'nopass'}) {
+      $cmd .= " -passout env:P12PASS";
+   } else {
+      $cmd .= " -passout pass:";
+   }
    $cmd .= " -passin env:SSLPASS";
    $cmd .= " -certfile $opts->{'cafile'}" if($opts->{'includeca'});
+   $cmd .= " -nodes " if($opts->{'nopass'});
+   $cmd .= " -name \"$opts->{'friendly'}\"" if($opts->{'friendly'} ne "");
 
-   $ENV{'P12PASS'} = $opts->{'p12passwd'};
+
+   $ENV{'P12PASS'} = $opts->{'p12passwd'} if(not $opts->{'nopass'});
    $ENV{'SSLPASS'} = $opts->{'passwd'};
    my($rdfh, $wtfh);
    $ext = "$cmd\n\n";
